==> aroundme_0_7_6.zip: aroundme_0_7_6/aroundme/components/core/language/1/barnraiser_01/participation.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// ARRAY LIBRARY TYPE
$lang['item_type_desc'][1] = 					"This SYS_KEYWORD_MODULE_NAME is an auto registration SYS_KEYWORD_MODULE_NAME which means you can join and automatically start participating.";
$lang['item_type_desc'][2] = 					"This SYS_KEYWORD_MODULE_NAME is a registration approval SYS_KEYWORD_MODULE_NAME which means you can join, but not participate until you registration is approved by an editor.";
$lang['item_type_desc'][3] = 					"This SYS_KEYWORD_MODULE_NAME is invitation only. You have been invited, so you can join the SYS_KEYWORD_MODULE_NAME if you would like to participate.";
$lang['item_type_desc'][4] = 					"This SYS_KEYWORD_MODULE_NAME is a membership type only SYS_KEYWORD_MODULE_NAME which means you can join and automatically start participating if you have an allowable membership type.";


// ERROR MESSAGES
$lang['error']['identity_empty'] = 				"You have not selected an identity to use in the SYS_KEYWORD_MODULE_NAME.";


//HEADER
$lang['hdr_my_participation'] = 				"my participation";
$lang['hdr_join'] = 							"join";
$lang['hdr_participants'] = 					"participants";
$lang['hdr_relations'] = 						"respected network";
$lang['hdr_participation'] = 					"participation";
$lang['hdr_invite'] = 							"invited by";


// SUBMIT BUTTONS
$lang['sub_update'] = 							"update";
$lang['sub_remove_relations'] = 				"remove from respected";
$lang['sub_join'] = 							"join";
$lang['sub_withdraw'] = 						"withdraw";
$lang['sub_invitation'] = 						"accept invitation";
$lang['sub_activate'] = 						"re-activate";


//BODY TEXT
$lang['txt_user_status'] = 						"status";
$lang['txt_editor'] = 							"editor";
$lang['txt_join_intro'] = 						"Select the identity that you wish to use inside this SYS_KEYWORD_MODULE_NAME then press 'join' or if you would no longer like to participate select 'withdraw'. Remember, once you join you cannot swap your identity for another one.";
$lang['txt_none'] = 							"none";
$lang['txt_mutual'] = 							"mutual";
$lang['txt_select_identity'] = 					"Select the identity that you wish to use inside this SYS_KEYWORD_MODULE_NAME then press 'join'.";


//MSG SUBJECT
$lang['txt_joined'] =							"Someone just accepted your invitation";
?>

==> aroundme_0_7_7.zip: aroundme_0_7_7/aroundme/components/core/language/1/barnraiser_01/participation.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// ARRAY LIBRARY TYPE
$lang['item_type_desc'][1] = 					"This SYS_KEYWORD_MODULE_NAME is an auto registration SYS_KEYWORD_MODULE_NAME which means you can join and automatically start participating.";
$lang['item_type_desc'][2] = 					"This SYS_KEYWORD_MODULE_NAME is a registration approval SYS_KEYWORD_MODULE_NAME which means you can join, but not participate until you registration is approved by an editor.";
$lang['item_type_desc'][3] = 					"This SYS_KEYWORD_MODULE_NAME is invitation only. You have been invited, so you can join the SYS_KEYWORD_MODULE_NAME if you would like to participate.";
$lang['item_type_desc'][4] = 					"This SYS_KEYWORD_MODULE_NAME is a membership type only SYS_KEYWORD_MODULE_NAME which means you can join and automatically start participating if you have an allowable membership type.";


// ERROR MESSAGES
$lang['error']['identity_empty'] = 				"You have not selected an identity to use in the SYS_KEYWORD_MODULE_NAME.";


//HEADER
$lang['hdr_my_participation'] = 				"my participation";
$lang['hdr_join'] = 							"join";
$lang['hdr_participants'] = 					"participants";
$lang['hdr_relations'] = 						"respected network";
$lang['hdr_participation'] = 					"participation";
$lang['hdr_invite'] = 							"invited by";


// SUBMIT BUTTONS
$lang['sub_update'] = 							"update";
$lang['sub_remove_relations'] = 				"remove from respected";
$lang['sub_join'] = 							"join";
$lang['sub_withdraw'] = 						"withdraw";
$lang['sub_invitation'] = 						"accept invitation";
$lang['sub_activate'] = 						"re-activate";


//BODY TEXT
$lang['txt_user_status'] = 						"status";
$lang['txt_editor'] = 							"editor";
$lang['txt_join_intro'] = 						"Select the identity that you wish to use inside this SYS_KEYWORD_MODULE_NAME then press 'join' or if you would no longer like to participate select 'withdraw'. Remember, once you join you cannot swap your identity for another one.";
$lang['txt_none'] = 							"none";
$lang['txt_mutual'] = 							"mutual";
$lang['txt_select_identity'] = 					"Select the identity that you wish to use inside this SYS_KEYWORD_MODULE_NAME then press 'join'.";
$lang['txt_one_identity'] =						"You will participate as 'SYS_KEYWORD_NAME'. Select help to find out more about identities.";

//MSG SUBJECT
$lang['txt_joined'] =							"Someone just accepted your invitation";
?>
